%  modelit.layout.Node - A node in a tree data structure.   
%  A node may have at most one parent and zero or more children.   
%  A node with no parent is the root of its tree; a node with no children is a leaf.   
%   
%  modelit.layout.Node Properties:   
%    allowsChildren - True if the node is able to have children.   
%    parent         - This node's parent, or empty if this node has no parent.   
%    rank           - Relative position of the node.   
%    children       - (Read only) Array of children,   
%    signature      - (Read only) Unique numeric signature (within objects of class Node)   
%   
%  modelit.layout.Node Methods:   
%    Node                      - modelit.layout.Node constructor.   
%    getPathToRoot             - Builds the parents of node up to and including the root node, where the original node is the last element in the returned array.   
%    getLevel                  - Returns the number of levels above this node, i.e. the distance from the root to this node.   
%    getDepthFirstList         - Creates a list on nodes in depth-first order for the subtree starting at the specified node.   
%    getBreadthFirstList       - Creates a list on nodes in breadth-first order for the subtree starting at the specified node.   
%    isactivenode              - Determine if a node is active.   
%    getBreadthFirstListActive - Create list of active frames only, see getBreadthFirstList.   
%    getPreviousSibling        - Returns the previous sibling of this node.   
%    getNextSibling            - Returns the next sibling of this node.   
%    getSiblings               - Gets the siblings (nodes with the same parent) of this node.   
%    removeAllChildren         - Removes all of this node's children.   
%    isRoot                    - Returns true if this node is the root of the tree.   
%    isLeaf                    - Returns true if this node is a leaf.   
%    getRoot                   - Returns the root of this node.   
%    getIndex                  - Returns the index of this node in its parent's children.   
%    getChildCount             - Returns the number of children of this node.   
%    getChildAt                - Returns the child of obj at index childIndex.   
%    getSortedChildren         - Returns the childs in sorted order.   
%    eq                        - Returns the objects whose property values match those passed as param-value pairs to the findobj command.   
%    findobj                   - Returns the objects whose property values match those passed as param-value pairs to the findobj command.   
%    ismember                  - Each node has its own unique numeric signature   
%    double                    -   
%    remove                    - Removes this node and its children from the tree.   
%    add                       - Removes newChild from its parent and makes it a child of this node by adding it to the end of this node's child array.   
   
   
% © Modelit 2006-2023   
% Matlab release: 2023a   
% Date: 2023/03/24 15:18:56   
