%  istableformat - check if S can be considered as a table structure   
%   
%  CALL   
%      [ok,N,emsg]=istable(S)   
%   
%  INPUT   
%      S: (candidate) table structure   
%   
%  OUTPUT   
%      ok  : true if S is table structure; false otherwise   
%      N   :  height of table   
%      emsg: <string> extra information if ok is false   
%   
%  TABLE DEFINITION (added by ZIJPP 2001225)   
%      A table structure is a structure that meets the following conventions.   
%   
%      - A table structure is a single structure with 0, 1 or more columns   
%      - If a table contains more than 1 column, all columns must be equal height   
%      - A column may be one ofd the following   
%        - a numeric or char array, including:   
%        - empty arrays ([0xW numeric or char])   
%        - vectors of NILL elements ([Hx0 numeric or char])   
%      - The preferred way to initialize an empty table structure is:   
%        T=struct ==> T= 1x1 struct array with no fields   
%      - By convention an empty scalar array or an empty struct array may be   
%        used to initialize an empty table structure:   
%        T=[] or T = struct([])   
%   
%  KNOWN ISSUES   
%      tableselect removes fieldnames if all rows of a table are removed   
%   
%  EXAMPLE   
%      if ~istable(S)   
%          error('Assertion failed: variable is not a table structure');   
%      end   
   
   
% © Modelit 2006-2023   
% Matlab release: 2023a   
% Date: 2023/03/24 15:18:56   
